@@ -5,10 +5,6 @@ import csv
 
 from sqlalchemy import engine_from_config
 
-CSV_HEADER =['urlname', 'parentname', 'baseref', 'result', 'warningstring',
-    'infostring', 'valid', 'url', 'line', 'column', 'name', 'dltime',
-    'dlsize', 'checktime', 'cached', 'level', 'modified']
-
 
 
 from pyramid.paster import (
@@ -20,26 +16,30 @@ from ..models import (
     DBSession,
     CheckedLink,
     Base,
+    CSV_HEADER,
     )
 
 
 def usage(argv):
     cmd = os.path.basename(argv[0])
-    print('usage: %s <config_uri>\n'
+    print('usage: %s <config_uri> [filename] \n'
           '(example: "%s development.ini")' % (cmd, cmd))
     sys.exit(1)
 
 
 def main(argv=sys.argv):
-    if len(argv) != 2:
+    if len(argv) < 2:
         usage(argv)
     config_uri = argv[1]
     setup_logging(config_uri)
     settings = get_appsettings(config_uri)
     engine = engine_from_config(settings, 'sqlalchemy.')
     DBSession.configure(bind=engine)
-    Base.metadata.create_all(engine)
-    fo = open('linkchecker-out.csv', 'rU')
+    Base.metadata.bind = engine
+    if len(argv) < 3:
+        fo = open('linkchecker-out.csv', 'rU')
+    else:
+        fo = open(argv[2], 'rU')
     reader=csv.reader(fo, delimiter=';')
     line = reader.next()
     while line[0].startswith('#'):
